require 'spec_helper'
require 'middleman_spec_helper'

describe BranchableCDNAssets::Middleman::Extension do

  before :each do
    Given.fixture('base')
    Given.file 'cdn/img_one', ''
    Given.file 'cdn/img_two', ''

    @mm = Middleman::Fixture.app

    @extension = @mm.extensions[:cdn_assets].first[1]
  end

  after :each do
    Given.cleanup!
  end

  describe "#config" do

    it "returns a Config instance" do
      expect( @extension.config.is_a?( BranchableCDNAssets::Config ) ).to be_truthy
    end

    it "sets config with extension options" do
      allow( Asgit ).to receive(:current_branch).and_return('master')
      @extension.options[:production_branch] = 'master'

      expect( @extension.config.host ).to eq 'production_host'
    end

    it "sets env to production if on :production_branch" do
      allow( Asgit ).to receive(:current_branch).and_return('master')
      @extension.options[:production_branch] = 'master'

      expect( @extension.config.env ).to eq :production
    end

    it "sets env to current_branch if there is a matching env key" do
      allow( Asgit ).to receive(:current_branch).and_return('test')

      expect( @extension.config.env ).to eq :test
    end

    it "falls back to :default_env if no matching env data" do
      allow( Asgit ).to receive(:current_branch).and_return('no_match')
      @extension.options[:default_env] = 'set_default_env'

      expect( @extension.config.env ).to eq :set_default_env
    end

  end

  describe "#manipulate_resource_list" do
    it "adds local files to the resource list" do
      resource_paths = @mm.sitemap.resources.map(&:url)
      expect( resource_paths ).to include "/assets/cdn/#{@extension.object_id}/img_one"
      expect( resource_paths ).to include "/assets/cdn/#{@extension.object_id}/img_two"
    end

    it "doesn't add local files when building"
  end

end